@@ -1,13 +1,14 @@
-#![allow(clippy::new_without_default)]
-
 #[cfg(not(any(feature = "bat-printer", feature = "syntect-printer")))]
 compile_error!("Either feature \"bat-printer\" or \"syntect-printer\" must be enabled");
 
-#[cfg(feature = "bat-printer")]
-pub mod bat;
 pub mod chunk;
 pub mod grep;
 pub mod printer;
+
+mod io;
+
+#[cfg(feature = "bat-printer")]
+pub mod bat;
 #[cfg(feature = "ripgrep")]
 pub mod ripgrep;
 #[cfg(feature = "syntect-printer")]
@@ -16,5 +17,4 @@ pub mod syntect;
 #[cfg(test)]
 mod test;
 
-pub use anyhow::Error;
-pub use anyhow::Result;
+pub use anyhow::{Error, Result};
