@@ -19,7 +19,7 @@ use hgrep::bat::BatPrinter;
 #[cfg(feature = "syntect-printer")]
 use hgrep::syntect::SyntectPrinter;
 
-fn command<'a>() -> Command<'a> {
+fn command() -> Command {
     #[cfg(feature = "syntect-printer")]
     const DEFAULT_PRINTER: &str = "syntect";
 
@@ -38,7 +38,7 @@ fn command<'a>() -> Command<'a> {
             Arg::new("min-context")
                 .short('c')
                 .long("min-context")
-                .takes_value(true)
+                .num_args(1)
                 .value_name("NUM")
                 .default_value("3")
                 .help("Minimum lines of leading and trailing context surrounding each match"),
@@ -47,7 +47,7 @@ fn command<'a>() -> Command<'a> {
             Arg::new("max-context")
                 .short('C')
                 .long("max-context")
-                .takes_value(true)
+                .num_args(1)
                 .value_name("NUM")
                 .default_value("6")
                 .help("Maximum lines of leading and trailing context surrounding each match"),
@@ -66,7 +66,7 @@ fn command<'a>() -> Command<'a> {
         .arg(
             Arg::new("tab")
                 .long("tab")
-                .takes_value(true)
+                .num_args(1)
                 .value_name("NUM")
                 .default_value("4")
                 .help("Number of spaces for tab character. Set 0 to pass tabs through directly"),
@@ -74,7 +74,7 @@ fn command<'a>() -> Command<'a> {
         .arg(
             Arg::new("theme")
                 .long("theme")
-                .takes_value(true)
+                .num_args(1)
                 .value_name("THEME")
                 .help("Theme for syntax highlighting. Use --list-themes flag to print the theme list"),
         )
@@ -94,16 +94,16 @@ fn command<'a>() -> Command<'a> {
         .arg(
             Arg::new("term-width")
                 .long("term-width")
-                .takes_value(true)
+                .num_args(1)
                 .value_name("NUM")
                 .help("Width (number of characters) of terminal window"),
         ).arg(
             Arg::new("wrap")
                 .long("wrap")
-                .takes_value(true)
+                .num_args(1)
                 .value_name("MODE")
                 .default_value("char")
-                .possible_values(["char", "never"])
+                .value_parser(["char", "never"])
                 .ignore_case(true)
                 .help("Text-wrapping mode. 'char' enables character-wise text-wrapping. 'never' disables text-wrapping")
         ).arg(
@@ -115,9 +115,9 @@ fn command<'a>() -> Command<'a> {
         .arg(
             Arg::new("generate-completion-script")
                 .long("generate-completion-script")
-                .takes_value(true)
+                .num_args(1)
                 .value_name("SHELL")
-                .possible_values(["bash", "zsh", "powershell", "fish", "elvish"])
+                .value_parser(["bash", "zsh", "powershell", "fish", "elvish"])
                 .ignore_case(true)
                 .help("Print completion script for SHELL to stdout"),
         );
@@ -180,9 +180,9 @@ fn command<'a>() -> Command<'a> {
                 Arg::new("glob")
                     .short('g')
                     .long("glob")
-                    .takes_value(true)
+                    .num_args(1)
                     .value_name("GLOB")
-                    .multiple_values(true)
+                    .num_args(1..)
                     .allow_hyphen_values(true)
                     .help("Include or exclude files and directories for searching that match the given glob"),
             )
@@ -234,14 +234,14 @@ fn command<'a>() -> Command<'a> {
                 Arg::new("max-count")
                     .short('m')
                     .long("max-count")
-                    .takes_value(true)
+                    .num_args(1)
                     .value_name("NUM")
                     .help("Limit the number of matching lines per file searched to NUM"),
             )
             .arg(
                 Arg::new("max-depth")
                     .long("max-depth")
-                    .takes_value(true)
+                    .num_args(1)
                     .value_name("NUM")
                     .help("Limit the depth of directory traversal to NUM levels beyond the paths given"),
             )
@@ -261,18 +261,18 @@ fn command<'a>() -> Command<'a> {
                 Arg::new("type")
                     .short('t')
                     .long("type")
-                    .takes_value(true)
+                    .num_args(1)
                     .value_name("TYPE")
-                    .multiple_occurrences(true)
+                    .action(clap::ArgAction::Append)
                     .help("Only search files matching TYPE. This option is repeatable. --type-list can print the list of types"),
             )
             .arg(
                 Arg::new("type-not")
                     .short('T')
                     .long("type-not")
-                    .takes_value(true)
+                    .num_args(1)
                     .value_name("TYPE")
-                    .multiple_occurrences(true)
+                    .action(clap::ArgAction::Append)
                     .help("Do not search files matching TYPE. Inverse of --type. This option is repeatable. --type-list can print the list of types"),
             )
             .arg(
@@ -283,7 +283,7 @@ fn command<'a>() -> Command<'a> {
             .arg(
                 Arg::new("max-filesize")
                     .long("max-filesize")
-                    .takes_value(true)
+                    .num_args(1)
                     .value_name("NUM+SUFFIX?")
                     .help("Ignore files larger than NUM in size. This does not apply to directories.The input format accepts suffixes of K, M or G which correspond to kilobytes, megabytes and gigabytes, respectively. If no suffix is provided the input is treated as bytes"),
             )
@@ -306,14 +306,14 @@ fn command<'a>() -> Command<'a> {
             .arg(
                 Arg::new("regex-size-limit")
                     .long("regex-size-limit")
-                    .takes_value(true)
+                    .num_args(1)
                     .value_name("NUM+SUFFIX?")
                     .help("The upper size limit of the compiled regex. The default limit is 10M. For the size suffixes, see --max-filesize"),
             )
             .arg(
                 Arg::new("dfa-size-limit")
                     .long("dfa-size-limit")
-                    .takes_value(true)
+                    .num_args(1)
                     .value_name("NUM+SUFFIX?")
                     .help("The upper size limit of the regex DFA. The default limit is 10M. For the size suffixes, see --max-filesize"),
             )
@@ -324,9 +324,9 @@ fn command<'a>() -> Command<'a> {
             .arg(
                 Arg::new("PATH")
                     .help("Paths to search")
-                    .multiple_values(true)
+                    .num_args(0..)
                     .value_hint(clap::ValueHint::AnyPath)
-                    .allow_invalid_utf8(true),
+                    .value_parser(clap::builder::ValueParser::path_buf()),
             );
 
     cmd
@@ -364,69 +364,68 @@ fn build_ripgrep_config(
     config
         .min_context(min_context)
         .max_context(max_context)
-        .no_ignore(matches.is_present("no-ignore"))
-        .hidden(matches.is_present("hidden"))
-        .case_insensitive(matches.is_present("ignore-case"))
-        .smart_case(matches.is_present("smart-case"))
-        .glob_case_insensitive(matches.is_present("glob-case-insensitive"))
-        .pcre2(matches.is_present("pcre2")) // must be before fixed_string
-        .fixed_strings(matches.is_present("fixed-strings"))
-        .word_regexp(matches.is_present("word-regexp"))
-        .follow_symlink(matches.is_present("follow-symlink"))
-        .multiline(matches.is_present("multiline"))
-        .crlf(matches.is_present("crlf"))
-        .multiline_dotall(matches.is_present("multiline-dotall"))
-        .mmap(matches.is_present("mmap"))
-        .line_regexp(matches.is_present("line-regexp"))
-        .invert_match(matches.is_present("invert-match"))
-        .one_file_system(matches.is_present("one-file-system"))
-        .no_unicode(matches.is_present("no-unicode"));
+        .no_ignore(matches.contains_id("no-ignore"))
+        .hidden(matches.contains_id("hidden"))
+        .case_insensitive(matches.contains_id("ignore-case"))
+        .smart_case(matches.contains_id("smart-case"))
+        .glob_case_insensitive(matches.contains_id("glob-case-insensitive"))
+        .pcre2(matches.contains_id("pcre2")) // must be before fixed_string
+        .fixed_strings(matches.contains_id("fixed-strings"))
+        .word_regexp(matches.contains_id("word-regexp"))
+        .follow_symlink(matches.contains_id("follow-symlink"))
+        .multiline(matches.contains_id("multiline"))
+        .crlf(matches.contains_id("crlf"))
+        .multiline_dotall(matches.contains_id("multiline-dotall"))
+        .mmap(matches.contains_id("mmap"))
+        .line_regexp(matches.contains_id("line-regexp"))
+        .invert_match(matches.contains_id("invert-match"))
+        .one_file_system(matches.contains_id("one-file-system"))
+        .no_unicode(matches.contains_id("no-unicode"));
 
-    let globs = matches.values_of("glob");
-    if let Some(globs) = globs {
-        config.globs(globs);
+    if let Some(globs) = matches.get_many::<String>("glob") {
+        config.globs(globs.map(String::as_str));
     }
 
-    if let Some(num) = matches.value_of("max-count") {
+    if let Some(num) = matches.get_one::<String>("max-count") {
         let num = num
             .parse()
             .context("could not parse --max-count option value as unsigned integer")?;
         config.max_count(num);
     }
 
-    if let Some(num) = matches.value_of("max-depth") {
+    if let Some(num) = matches.get_one::<String>("max-depth") {
         let num = num
             .parse()
             .context("could not parse --max-depth option value as unsigned integer")?;
         config.max_depth(num);
     }
 
-    if let Some(size) = matches.value_of("max-filesize") {
+    if let Some(size) = matches.get_one::<String>("max-filesize") {
         config
             .max_filesize(size)
-            .context("coult not parse --max-filesize option value as file size string")?;
+            .context("could not parse --max-filesize option value as file size string")?;
     }
 
-    if let Some(limit) = matches.value_of("regex-size-limit") {
+    if let Some(limit) = matches.get_one::<String>("regex-size-limit") {
         config
             .regex_size_limit(limit)
-            .context("coult not parse --regex-size-limit option value as size string")?;
+            .context("could not parse --regex-size-limit option value as size string")?;
     }
 
-    if let Some(limit) = matches.value_of("dfa-size-limit") {
+    if let Some(limit) = matches.get_one::<String>("dfa-size-limit") {
         config
             .dfa_size_limit(limit)
-            .context("coult not parse --dfa-size-limit option value as size string")?;
+            .context("could not parse --dfa-size-limit option value as size string")?;
     }
 
-    let types = matches.values_of("type");
+    let types = matches.get_many::<String>("type");
     if let Some(types) = types {
-        config.types(types);
+        config.types(types.map(String::as_str));
     }
 
-    let types_not = matches.values_of("type-not");
+    let types_not = matches.get_many::<String>("type-not");
     if let Some(types_not) = types_not {
-        config.types_not(types_not);
+        config.types_not(types_not.map(String::as_str));
     }
 
     Ok(config)
@@ -442,13 +441,13 @@ enum PrinterKind {
 
 fn app() -> Result<bool> {
     let matches = command().get_matches();
-    if let Some(shell) = matches.value_of("generate-completion-script") {
+    if let Some(shell) = matches.get_one::<String>("generate-completion-script") {
         generate_completion_script(shell);
         return Ok(true);
     }
 
     #[allow(unused_variables)] // printer_kind is unused when syntect-printer is disabled for now
-    let printer_kind = match matches.value_of("printer").unwrap() {
+    let printer_kind = match matches.get_one::<String>("printer").unwrap().as_str() {
         #[cfg(feature = "bat-printer")]
         "bat" => PrinterKind::Bat,
         #[cfg(not(feature = "bat-printer"))]
@@ -461,19 +460,19 @@ fn app() -> Result<bool> {
     };
 
     let min_context = matches
-        .value_of("min-context")
+        .get_one::<String>("min-context")
         .unwrap()
         .parse()
         .context("could not parse \"min-context\" option value as unsigned integer")?;
     let max_context = matches
-        .value_of("max-context")
+        .get_one::<String>("max-context")
         .unwrap()
         .parse()
         .context("could not parse \"max-context\" option value as unsigned integer")?;
     let max_context = cmp::max(min_context, max_context);
 
     let mut printer_opts = PrinterOptions::default();
-    if let Some(width) = matches.value_of("tab") {
+    if let Some(width) = matches.get_one::<String>("tab") {
         printer_opts.tab_width = width
             .parse()
             .context("could not parse \"tab\" option value as unsigned integer")?;
@@ -487,11 +486,11 @@ fn app() -> Result<bool> {
             printer_opts.theme = Some(var);
         }
     }
-    if let Some(theme) = matches.value_of("theme") {
+    if let Some(theme) = matches.get_one::<String>("theme") {
         printer_opts.theme = Some(theme);
     }
 
-    let is_grid = matches.is_present("grid");
+    let is_grid = matches.contains_id("grid");
     #[cfg(feature = "bat-printer")]
     if printer_kind == PrinterKind::Bat {
         if let Ok("plain" | "header" | "numbers") =
@@ -502,11 +501,11 @@ fn app() -> Result<bool> {
             }
         }
     }
-    if matches.is_present("no-grid") && !is_grid {
+    if matches.contains_id("no-grid") && !is_grid {
         printer_opts.grid = false;
     }
 
-    if let Some(width) = matches.value_of("term-width") {
+    if let Some(width) = matches.get_one::<String>("term-width") {
         let width = width
             .parse()
             .context("could not parse \"term-width\" option value as unsigned integer")?;
@@ -516,7 +515,7 @@ fn app() -> Result<bool> {
         }
     }
 
-    if let Some(mode) = matches.value_of("wrap") {
+    if let Some(mode) = matches.get_one::<String>("wrap") {
         if mode.eq_ignore_ascii_case("never") {
             printer_opts.text_wrap = TextWrapMode::Never;
         } else if mode.eq_ignore_ascii_case("char") {
@@ -526,13 +525,13 @@ fn app() -> Result<bool> {
         }
     }
 
-    if matches.is_present("first-only") {
+    if matches.contains_id("first-only") {
         printer_opts.first_only = true;
     }
 
     #[cfg(feature = "syntect-printer")]
     {
-        if matches.is_present("background") {
+        if matches.contains_id("background") {
             printer_opts.background_color = true;
             #[cfg(feature = "bat-printer")]
             if printer_kind == PrinterKind::Bat {
@@ -540,7 +539,7 @@ fn app() -> Result<bool> {
             }
         }
 
-        if matches.is_present("ascii-lines") {
+        if matches.contains_id("ascii-lines") {
             printer_opts.ascii_lines = true;
             #[cfg(feature = "bat-printer")]
             if printer_kind == PrinterKind::Bat {
@@ -550,7 +549,7 @@ fn app() -> Result<bool> {
     }
 
     #[cfg(feature = "bat-printer")]
-    if matches.is_present("custom-assets") {
+    if matches.contains_id("custom-assets") {
         printer_opts.custom_assets = true;
         #[cfg(feature = "syntect-printer")]
         if printer_kind == PrinterKind::Syntect {
@@ -558,7 +557,7 @@ fn app() -> Result<bool> {
         }
     }
 
-    if matches.is_present("list-themes") {
+    if matches.contains_id("list-themes") {
         #[cfg(feature = "syntect-printer")]
         if printer_kind == PrinterKind::Syntect {
             hgrep::syntect::list_themes(io::stdout().lock(), &printer_opts)?;
@@ -575,15 +574,19 @@ fn app() -> Result<bool> {
     }
 
     #[cfg(feature = "ripgrep")]
-    if matches.is_present("type-list") {
+    if matches.contains_id("type-list") {
         let config = build_ripgrep_config(min_context, max_context, &matches)?;
         config.print_types(io::stdout().lock())?;
         return Ok(true);
     }
 
     #[cfg(feature = "ripgrep")]
-    if let Some(pattern) = matches.value_of("PATTERN") {
-        let paths = matches.values_of_os("PATH");
+    if let Some(pattern) = matches.get_one::<String>("PATTERN") {
+        use std::path::PathBuf;
+
+        let paths = matches
+            .get_many::<PathBuf>("PATH")
+            .map(|p| p.map(PathBuf::as_path));
         let config = build_ripgrep_config(min_context, max_context, &matches)?;
 
         #[cfg(feature = "syntect-printer")]
