@@ -12,10 +12,9 @@ use ignore::{Walk, WalkBuilder};
 use rayon::iter::ParallelBridge;
 use rayon::prelude::*;
 use std::env;
-use std::ffi::OsStr;
 use std::fs::File;
 use std::io;
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 use std::sync::Mutex;
 
 // Note: 'main is a lifetime of scope of main() function
@@ -228,7 +227,7 @@ impl<'main> Config<'main> {
         Ok(self)
     }
 
-    fn build_walker(&self, mut paths: impl Iterator<Item = &'main OsStr>) -> Result<Walk> {
+    fn build_walker(&self, mut paths: impl Iterator<Item = &'main Path>) -> Result<Walk> {
         let target = paths.next().unwrap();
 
         let mut builder = OverrideBuilder::new(target);
@@ -394,14 +393,14 @@ impl<'main> Config<'main> {
 pub fn grep<'main, P: Printer + Sync>(
     printer: P,
     pat: &str,
-    paths: Option<impl Iterator<Item = &'main OsStr>>,
+    paths: Option<impl Iterator<Item = &'main Path>>,
     config: Config<'main>,
 ) -> Result<bool> {
     let entries = if let Some(paths) = paths {
         config.build_walker(paths)?
     } else {
         let cwd = env::current_dir()?;
-        let paths = std::iter::once(cwd.as_os_str());
+        let paths = std::iter::once(cwd.as_path());
         config.build_walker(paths)?
     };
 
@@ -678,7 +677,7 @@ mod tests {
             let mut printer = DummyPrinter::default();
             let pat = r"\*$";
             let file = dir.join(format!("{}.in", input));
-            let paths = iter::once(OsStr::new(&file));
+            let paths = iter::once(file.as_path());
             let found = grep(&printer, pat, Some(paths), Config::new(3, 6)).unwrap();
             let expected = read_expected_chunks(&dir, input)
                 .map(|f| vec![f])
@@ -722,7 +721,7 @@ mod tests {
     #[test]
     fn test_grep_no_match_found() {
         let path = Path::new("testdata").join("chunk").join("single_max.in");
-        let paths = iter::once(path.as_os_str());
+        let paths = iter::once(path.as_path());
         let printer = DummyPrinter::default();
         let pat = "^this does not match to any line!!!!!!$";
         let found = grep(&printer, pat, Some(paths), Config::new(3, 6)).unwrap();
@@ -739,7 +738,7 @@ mod tests {
                 .join("this-file-does-not-exist.txt"),
             Path::new("testdata").join("this-directory-dies-not-exist"),
         ] {
-            let paths = iter::once(path.as_os_str());
+            let paths = iter::once(path.as_path());
             let printer = DummyPrinter::default();
             let pat = ".*";
             grep(&printer, pat, Some(paths), Config::new(3, 6)).unwrap_err();
@@ -757,7 +756,7 @@ mod tests {
     #[test]
     fn test_grep_print_error() {
         let path = Path::new("testdata").join("chunk").join("single_max.in");
-        let paths = iter::once(path.as_os_str());
+        let paths = iter::once(path.as_path());
         let pat = ".*";
         let err = grep(ErrorPrinter, pat, Some(paths), Config::new(3, 6)).unwrap_err();
         let msg = format!("{}", err);
@@ -825,7 +824,7 @@ mod tests {
 
     fn test_ripgrep_config(file: &str, pat: &str, f: fn(&mut Config) -> ()) {
         let path = Path::new("testdata").join("ripgrep").join(file);
-        let paths = iter::once(path.as_os_str());
+        let paths = iter::once(path.as_path());
         let printer = DummyPrinter::default();
 
         let mut config = Config::new(1, 2);
@@ -985,11 +984,12 @@ mod tests {
 
         for (input, want) in tests.iter().copied() {
             let mut c = Config::default();
-            let mut errs = vec![];
-            errs.push(("max-filesize", c.max_filesize(input).err()));
-            errs.push(("regex-size-limit", c.regex_size_limit(input).err()));
-            errs.push(("dfa-size-limit", c.dfa_size_limit(input).err()));
-            for (opt, err) in errs.into_iter() {
+            let errs = [
+                ("max-filesize", c.max_filesize(input).err()),
+                ("regex-size-limit", c.regex_size_limit(input).err()),
+                ("dfa-size-limit", c.dfa_size_limit(input).err()),
+            ];
+            for (opt, err) in errs {
                 match want {
                     Ok(want) => assert_eq!(
                         c.max_filesize,
